package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.DictionaryInfoDTO;
import com.diagbot.entity.KlDictionaryInfo;
import com.diagbot.entity.KlLexicon;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.impl.KlDictionaryInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.ListUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2021/2/25 16:48
 */
@Component
public class KlDictionaryInfoFacade extends KlDictionaryInfoServiceImpl {

    @Autowired
    KlLexiconFacade klLexiconFacade;

    /**
     * 返回字典信息
     *
     * @return
     */
    public Map<Long, List<DictionaryInfoDTO>> getList() {
        List<KlDictionaryInfo> list = this.list(new QueryWrapper<KlDictionaryInfo>()
                .in("return_type", ListUtil.arrayToList(new Long[] { 0L, 2L }))
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .orderByAsc("group_type", "order_no"));
        List<DictionaryInfoDTO> listRes = BeanUtil.listCopyTo(list, DictionaryInfoDTO.class);
        return EntityUtil.makeEntityListMap(listRes, "groupType");
    }

    /**
     * 返回字典信息
     *
     * @return
     */
    public Map<Long, List<DictionaryInfoDTO>> getListBack() {
        List<KlDictionaryInfo> list = this.list(new QueryWrapper<KlDictionaryInfo>()
                .in("return_type", ListUtil.arrayToList(new Long[] { 0L, 1L }))
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .orderByAsc("group_type", "order_no"));
        List<DictionaryInfoDTO> listRes = BeanUtil.listCopyTo(list, DictionaryInfoDTO.class);

        // 添加词库类型
        List<KlLexicon> lexiconList = klLexiconFacade.list(new QueryWrapper<KlLexicon>().lambda()
                .eq(KlLexicon::getIsDeleted, IsDeleteEnum.N.getKey()));
        for (KlLexicon klLexicon : lexiconList) {
            DictionaryInfoDTO dictionaryInfoDTO = new DictionaryInfoDTO();
            dictionaryInfoDTO.setGroupType(-100L);
            dictionaryInfoDTO.setName(klLexicon.getName());
            dictionaryInfoDTO.setVal(String.valueOf(klLexicon.getCode()));
            dictionaryInfoDTO.setOrderNo(klLexicon.getId().intValue());
            dictionaryInfoDTO.setRemark("词库类型");
            listRes.add(dictionaryInfoDTO);
        }

        return EntityUtil.makeEntityListMap(listRes, "groupType");
    }

    /**
     * 返回指定字典信息
     *
     * @param groupType
     * @return
     */
    public List<DictionaryInfoDTO> getListByGroupType(Integer groupType) {
        List<KlDictionaryInfo> list = this.list(new QueryWrapper<KlDictionaryInfo>()
                .eq("group_type", groupType)
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .orderByAsc("order_no"));
        List<DictionaryInfoDTO> listRes = BeanUtil.listCopyTo(list, DictionaryInfoDTO.class);
        return listRes;
    }

    /**
     * 返回指定字典信息
     *
     * @param groupType
     * @return
     */
    public List<DictionaryInfoDTO> getListByGroupType(List<Integer> groupType) {
        List<KlDictionaryInfo> list = this.list(new QueryWrapper<KlDictionaryInfo>()
                .in("group_type", groupType)
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .orderByAsc("group_type", "order_no"));
        List<DictionaryInfoDTO> listRes = BeanUtil.listCopyTo(list, DictionaryInfoDTO.class);
        return listRes;
    }
}
